@@ -830,8 +830,8 @@ class Stream_Enhancer:
                 self.telegramlast=telegramnow
             else:
                 print("i.. telegram not allowed due time", (telegramnow-self.telegramlast).total_seconds())
-        else:
-            print(f"X...  jtele=={self.jtelegram}, token")
+        #else:
+        #    print(f"X...  jtele=={self.jtelegram}, token")
         return
 
 
@@ -882,7 +882,9 @@ class Stream_Enhancer:
 
             self.aviout.write(self.frame)
             # plan telegram send to future
-            if type(self.telegramtrigger)==bool:
+            # bool means it is not set....
+            #
+            if self.jtelegram and type(self.telegramtrigger)==bool:
                 self.telegramtrigger = dt.datetime.now()+dt.timedelta(seconds=2)
                 print("i... telegramtrigger preset to +2 sec.",self.telegramtrigger.strftime("%H:%M:%S"))
             # MOMENT WHEN AVI IS SAVED===========> imagezmq, telegram...
